@@ -7,7 +7,7 @@
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model 2.145;
+package Config::Model 2.146;
 
 use 5.20.0;
 use strict ;
@@ -1896,7 +1896,7 @@ Config::Model - a framework to validate, migrate and edit configuration files
 
 =head1 VERSION
 
-version 2.145
+version 2.146
 
 =head1 SYNOPSIS
 
@@ -2778,7 +2778,7 @@ Dominique Dumont, "ddumont@cpan.org"
 
 =head1 CREDITS
 
-In alphabetical order:
+Contributors to this project are listed in alphabetical order:
 
   Harley Pig
 
@@ -2792,24 +2792,9 @@ In alphabetical order:
 
   Mohammad S Anwar
 
-=head1 LICENSE
+  Topi Miettinen
 
-    Copyright (c) 2005-2016 Dominique Dumont.
-
-    Config-Model is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public License as
-    published by the Free Software Foundation; either version 2.1 of
-    the License, or (at your option) any later version.
-
-    Config-Model is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public License
-    along with Config-Model; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-    02110-1301 USA
+Many thanks for your help
 
 =head1 SEE ALSO
 
