@@ -7,7 +7,7 @@
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Instance 2.145;
+package Config::Model::Instance 2.146;
 
 #use Scalar::Util qw(weaken) ;
 use strict;
@@ -386,7 +386,9 @@ sub modify {
     my $self = shift ;
     my %args   = @_ eq 1 ? ( step => $_[0] ) : @_;
     my $force = delete $args{force_save} || delete $args{force};
+    my $quiet = delete $args{quiet};
     $self->load(%args)->write_back( force => $force );
+    $self->say_changes() unless $quiet;
     return $self;
 }
 
@@ -665,7 +667,7 @@ Config::Model::Instance - Instance of configuration tree
 
 =head1 VERSION
 
-version 2.145
+version 2.146
 
 =head1 SYNOPSIS
 
@@ -814,8 +816,20 @@ C<< check => 'no' >> ).
 
 Calls L</"load"> and then L</save>.
 
-Takes the same parameter as C<load> plus C<force_write> to force
-saving configuration file even if no value was modified (default is 0)
+Takes the same parameter as C<load> plus:
+
+=over
+
+=item C<force_write>
+
+Force saving configuration file even if no value was modified
+(default is 0)
+
+=item C<quiet>
+
+Do no display the changes brought by the modification steps
+
+=back
 
 =head2 load
 
